@@ -16,7 +16,7 @@ int main(int argc, char *argv[])
     QObject::connect(
             &engine, &QQmlApplicationEngine::objectCreationFailed, &app,
             []() { QCoreApplication::exit(1); }, Qt::QueuedConnection);
-    engine.loadFromModule("NdefEditor", "Main");
+    engine.loadFromModule("NdefEditorModule", "Main");
 
     return app.exec();
 }
