@@ -3,12 +3,10 @@
 
 #include "bookwindow.h"
 
-#include <QtWidgets>
+#include <QApplication>
 
 int main(int argc, char * argv[])
 {
-    Q_INIT_RESOURCE(books);
-
     QApplication app(argc, argv);
 
     BookWindow win;
